##########################
Orange Scripting Reference
##########################

.. toctree::
   :maxdepth: 2

   Orange.data

   Orange.feature

   Orange.classification

   Orange.regression
   
   Orange.statistics
   
   Orange.ensemble

   Orange.evaluation

   Orange.multilabel
   
   Orange.associate

   Orange.clustering

   Orange.distance

   Orange.tuning
   
   Orange.projection

   Orange.misc

   Orange.utils

****************
Index and search
****************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
